@@ -1811,8 +1811,12 @@ static int DoCalRem(ParsePtr p, int col)
 	FindToken(DBufValue(&buf), &tok);
 	DBufFree(&buf);
 	if (tok.type == T_Empty || tok.type == T_Comment) {
+            r = OK;
+            if (trig.addomit) {
+                r = AddGlobalOmit(LastTriggerDate);
+            }
 	    FreeTrig(&trig);
-	    return OK;
+	    return r;
 	}
 	if (tok.type != T_RemType || tok.val == SAT_TYPE) {
 	    FreeTrig(&trig);
@@ -1830,6 +1834,10 @@ static int DoCalRem(ParsePtr p, int col)
 	    DBufFree(&buf);
 	}
 	trig.typ = tok.val;
+
+        /* Convert some SPECIALs back to plain types */
+        FixSpecialType(&trig);
+
         if (trig.typ == MSG_TYPE ||
             trig.typ == CAL_TYPE ||
             trig.typ == MSF_TYPE) {
