@@ -123,8 +123,12 @@ int DoRem(ParsePtr p)
 	    }
 	    StrnCpy(trig.passthru, DBufValue(&buf), PASSTHRU_LEN);
 	    DBufFree(&buf);
-	}
-	trig.typ = tok.val;
+        }
+        trig.typ = tok.val;
+
+        /* Convert some SPECIALs back to plain types */
+        FixSpecialType(&trig);
+
 	dse = LastTriggerDate;
 	if (!LastTrigValid || PurgeMode) {
 	    FreeTrig(&trig);
@@ -188,7 +192,7 @@ int DoRem(ParsePtr p)
 
     r = OK;
     if (ShouldTriggerReminder(&trig, &tim, dse, &err)) {
-	if ( (r=TriggerReminder(p, &trig, &tim, dse)) ) {
+	if ( (r=TriggerReminder(p, &trig, &tim, dse, 0)) ) {
 	    FreeTrig(&trig);
 	    return r;
 	}
@@ -370,6 +374,7 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim, int save_in_globals)
 		}
 		StrnCpy(trig->passthru, DBufValue(&buf), PASSTHRU_LEN);
 	    }
+            FixSpecialType(trig);
             parsing = 0;
             break;
 
@@ -893,7 +898,7 @@ static int ParseScanFrom(ParsePtr s, Trigger *t, int type)
 /*  Trigger the reminder if it's a RUN or MSG type.            */
 /*                                                             */
 /***************************************************************/
-int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int dse)
+int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int dse, int is_queued)
 {
     int r, y, m, d;
     char PrioExpr[VAR_NAME_LEN+25];
@@ -901,8 +906,21 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int dse)
     DynamicBuffer buf, calRow;
     DynamicBuffer pre_buf;
     char const *s;
+    char const *msg_command = NULL;
     Value v;
 
+    if (MsgCommand) {
+        msg_command = MsgCommand;
+    }
+    if (is_queued && QueuedMsgCommand) {
+        msg_command = QueuedMsgCommand;
+    }
+
+    /* A null command is no command */
+    if (msg_command && !*msg_command) {
+        msg_command = NULL;
+    }
+
     int red = -1, green = -1, blue = -1;
     int is_color = 0;
 
@@ -947,7 +965,7 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int dse)
     }
 /* If it's a MSG-type reminder, and no -k option was used, issue the banner. */
     if ((t->typ == MSG_TYPE || t->typ == MSF_TYPE) 
-	&& !DidMsgReminder && !NextMode && !MsgCommand) {
+	&& !DidMsgReminder && !NextMode && !msg_command) {
         DidMsgReminder = 1;
 	if (!DoSubstFromString(DBufValue(&Banner), &buf,
 			       DSEToday, NO_TIME) &&
@@ -1091,7 +1109,7 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int dse)
 	DBufPuts(&buf, Decolorize());
     }
 
-    if ((!MsgCommand && t->typ == MSG_TYPE) || t->typ == MSF_TYPE) {
+    if ((!msg_command && t->typ == MSG_TYPE) || t->typ == MSF_TYPE) {
 	if (DBufPutc(&buf, '\n') != OK) {
 	    DBufFree(&buf);
 	    return E_NO_MEM;
@@ -1113,8 +1131,8 @@ int TriggerReminder(ParsePtr p, Trigger *t, TimeTrig *tim, int dse)
     switch(t->typ) {
     case MSG_TYPE:
     case PASSTHRU_TYPE:
-	if (MsgCommand) {
-	    DoMsgCommand(MsgCommand, DBufValue(&buf));
+	if (msg_command) {
+	    DoMsgCommand(msg_command, DBufValue(&buf));
 	} else {
 	    printf("%s", DBufValue(&buf));
 	}
@@ -1466,3 +1484,25 @@ static int ShouldTriggerBasedOnWarn(Trigger *t, int dse, int *err)
 	}
     }
 }
+
+void FixSpecialType(Trigger *t)
+{
+    if (t->typ != PASSTHRU_TYPE) {
+        return;
+    }
+
+    /* Convert SPECIAL MSG / MSF / RUN / CAL to just plain MSG / MSF / etc */
+    if (!StrCmpi(t->passthru, "MSG")) {
+        t->typ = MSG_TYPE;
+    } else if (!StrCmpi(t->passthru, "MSF")) {
+        t->typ = MSF_TYPE;
+    } else if (!StrCmpi(t->passthru, "RUN")) {
+        t->typ = RUN_TYPE;
+    } else if (!StrCmpi(t->passthru, "CAL")) {
+        t->typ = CAL_TYPE;
+    } else if (!StrCmpi(t->passthru, "PS")) {
+        t->typ = PS_TYPE;
+    } else if (!StrCmpi(t->passthru, "PSFILE")) {
+        t->typ = PSF_TYPE;
+    }
+}
