@@ -5,7 +5,8 @@
 /*  Routines for figuring out the trigger date of a reminder   */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2022 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2023 by Dianne Skoll                    */
+/*  SPDX-License-Identifier: GPL-2.0-only                      */
 /*                                                             */
 /***************************************************************/
 
@@ -26,8 +27,8 @@
 
 #define ADVANCE_TO_WD(x, wd) while (! ((wd) & (1 << ((x)%7)))) (x)++
 
-static int JYear(int jul);
-static int JMonth(int jul);
+static int DSEYear(int dse);
+static int DSEMonth(int dse);
 static int NextSimpleTrig(int startdate, Trigger *trig, int *err);
 static int GetNextTriggerDate(Trigger *trig, int start, int *err, int *nextstart);
 
@@ -39,7 +40,7 @@ static int GetNextTriggerDate(Trigger *trig, int start, int *err, int *nextstart
 /*  ONLY the day of week, day, month and year components.      */
 /*  Normally, returns -1 if the trigger has expired.  As a     */
 /*  special case, if D, M, Y [WD] are specified, returns the   */
-/*  Julian date, regardless of whether it's expired.  This is  */
+/*  DSE date, regardless of whether it's expired.  This is     */
 /*  so that dates with a REP can be handled properly.          */
 /*                                                             */
 /***************************************************************/
@@ -49,7 +50,7 @@ static int NextSimpleTrig(int startdate, Trigger *trig, int *err)
     int d, m, y, j, d2, m2, y2;
 
     *err = 0;
-    FromJulian(startdate, &y, &m, &d);
+    FromDSE(startdate, &y, &m, &d);
     d2 = d;
     m2 = m;
     y2 = y;
@@ -72,17 +73,17 @@ static int NextSimpleTrig(int startdate, Trigger *trig, int *err)
 	    if (m == 12) { m = 0; y++; }
 	}
 	while (trig->d > DaysInMonth(m, trig->y)) m++;
-	j = Julian(y, m, trig->d);
+	j = DSE(y, m, trig->d);
 	return j;
 
     case GOT_MON:
 	if (m == trig->m) return startdate;
-	else if (m > trig->m) return Julian(y+1, trig->m, 1);
-	else return Julian(y, trig->m, 1);
+	else if (m > trig->m) return DSE(y+1, trig->m, 1);
+	else return DSE(y, trig->m, 1);
 
     case GOT_YR:
 	if (y == trig->y) return startdate;
-	else if (y < trig->y) return Julian(trig->y, 0, 1);
+	else if (y < trig->y) return DSE(trig->y, 0, 1);
 	else return -1;
 
     case GOT_DAY+GOT_MON:
@@ -94,10 +95,10 @@ static int NextSimpleTrig(int startdate, Trigger *trig, int *err)
 	if (m > trig->m || (m == trig->m && d > trig->d)) y++;
 	/* Take care of Feb. 29 */
 	while (trig->d > DaysInMonth(trig->m, y)) y++;
-	return Julian(y, trig->m, trig->d);
+	return DSE(y, trig->m, trig->d);
 
     case GOT_DAY+GOT_YR:
-	if (y < trig->y) return Julian(trig->y, 0, trig->d);
+	if (y < trig->y) return DSE(trig->y, 0, trig->d);
 	else if (y > trig->y) return -1;
 
 	if (d > trig->d) {
@@ -105,37 +106,37 @@ static int NextSimpleTrig(int startdate, Trigger *trig, int *err)
 	    if (m == 12) return -1;
 	}
 	while (trig->d > DaysInMonth(m, trig->y)) m++;
-	return Julian(trig->y, m, trig->d);
+	return DSE(trig->y, m, trig->d);
 
     case GOT_MON+GOT_YR:
 	if (y > trig->y || (y == trig->y && m > trig->m)) return -1;
-	if (y < trig->y) return Julian(trig->y, trig->m, 1);
+	if (y < trig->y) return DSE(trig->y, trig->m, 1);
 	if (m == trig->m) return startdate;
-	return Julian(trig->y, trig->m, 1);
+	return DSE(trig->y, trig->m, 1);
 
     case GOT_DAY+GOT_MON+GOT_YR:
 	if (trig->d > DaysInMonth(trig->m, trig->y)) {
 	    *err = E_BAD_DATE;
 	    return -1;
 	}
-	return Julian(trig->y, trig->m, trig->d);
+	return DSE(trig->y, trig->m, trig->d);
 
     case GOT_YR+GOT_WD:
 	if (y > trig->y) return -1;
-	if (y < trig->y) j = Julian(trig->y, 0, 1);
+	if (y < trig->y) j = DSE(trig->y, 0, 1);
 	else j = startdate;
         ADVANCE_TO_WD(j, trig->wd);
-	if (JYear(j) > trig->y) return -1;
+	if (DSEYear(j) > trig->y) return -1;
 	return j;
 
     case GOT_MON+GOT_WD:
 	if (m == trig->m) {
 	    j = startdate;
             ADVANCE_TO_WD(j, trig->wd);
-	    if (JMonth(j) == trig->m) return j;
+	    if (DSEMonth(j) == trig->m) return j;
 	}
-	if (m >= trig->m) j = Julian(y+1, trig->m, 1);
-	else j = Julian(y, trig->m, 1);
+	if (m >= trig->m) j = DSE(y+1, trig->m, 1);
+	else j = DSE(y, trig->m, 1);
         ADVANCE_TO_WD(j, trig->wd);
 	return j; /* Guaranteed to be within the month */
 
@@ -146,7 +147,7 @@ static int NextSimpleTrig(int startdate, Trigger *trig, int *err)
 
 	    /* If there are fewer days in previous month, no match */
 	    if (trig->d <= DaysInMonth(m2, y2)) {
-		j = Julian(y2, m2, trig->d);
+		j = DSE(y2, m2, trig->d);
                 ADVANCE_TO_WD(j, trig->wd);
 		if (j >= startdate) return j;
 
@@ -155,7 +156,7 @@ static int NextSimpleTrig(int startdate, Trigger *trig, int *err)
 
 	/* Try this month */
 	if (trig->d <= DaysInMonth(m, y)) {
-	    j = Julian(y, m, trig->d);
+	    j = DSE(y, m, trig->d);
             ADVANCE_TO_WD(j, trig->wd);
 	    if (j >= startdate) return j;
 	}
@@ -164,18 +165,18 @@ static int NextSimpleTrig(int startdate, Trigger *trig, int *err)
 	m2 = m+1;
 	if (m2 > 11) { m2 = 0; y++; }
 	while (trig->d > DaysInMonth(m2, y)) m2++;
-	j = Julian(y, m2, trig->d);
+	j = DSE(y, m2, trig->d);
         ADVANCE_TO_WD(j, trig->wd);
 	return j;
 
     case GOT_WD+GOT_YR+GOT_DAY:
 	if (y > trig->y+1 || (y > trig->y && m>0)) return -1;
 	if (y > trig->y) {
-	    j = Julian(trig->y, 11, trig->d);
+	    j = DSE(trig->y, 11, trig->d);
             ADVANCE_TO_WD(j, trig->wd);
 	    if (j >= startdate) return j;
 	} else if (y < trig->y) {
-	    j = Julian(trig->y, 0, trig->d);
+	    j = DSE(trig->y, 0, trig->d);
             ADVANCE_TO_WD(j, trig->wd);
 	    return j;
 	} else {
@@ -183,17 +184,17 @@ static int NextSimpleTrig(int startdate, Trigger *trig, int *err)
 	    if (m > 0) {
 		m2 = m-1;
 		while (trig->d > DaysInMonth(m2, trig->y)) m2--;
-		j = Julian(trig->y, m2, trig->d);
+		j = DSE(trig->y, m2, trig->d);
                 ADVANCE_TO_WD(j, trig->wd);
-                if (JYear(j) > trig->y) return -1;
+                if (DSEYear(j) > trig->y) return -1;
 		if (j >= startdate) return j;
 	    }
 	}
 	/* Try this month */
 	if (trig->d <= DaysInMonth(m, trig->y)) {
-	    j = Julian(trig->y, m, trig->d);
+	    j = DSE(trig->y, m, trig->d);
             ADVANCE_TO_WD(j, trig->wd);
-            if (JYear(j) > trig->y) return -1;
+            if (DSEYear(j) > trig->y) return -1;
 	    if (j >= startdate) return j;
 	}
 
@@ -201,9 +202,9 @@ static int NextSimpleTrig(int startdate, Trigger *trig, int *err)
 	if (m == 11) return -1;
 	m++;
 	while (trig->d > DaysInMonth(m, trig->d)) m++;
-	j = Julian(trig->y, m, trig->d);
+	j = DSE(trig->y, m, trig->d);
         ADVANCE_TO_WD(j, trig->wd);
-        if (JYear(j) > trig->y) return -1;
+        if (DSEYear(j) > trig->y) return -1;
 	return j;
 
     case GOT_DAY+GOT_MON+GOT_WD:
@@ -220,34 +221,34 @@ static int NextSimpleTrig(int startdate, Trigger *trig, int *err)
 	while (trig->d > DaysInMonth(trig->m, y)) y++;
 
 	/* Try last year */
-	j = Julian(y, trig->m, trig->d);
+	j = DSE(y, trig->m, trig->d);
         ADVANCE_TO_WD(j, trig->wd);
 	if (j >= startdate) return j;
 
 	/* Try this year */
 	y++;
 	while (trig->d > DaysInMonth(trig->m, y)) y++;
-	j = Julian(y, trig->m, trig->d);
+	j = DSE(y, trig->m, trig->d);
         ADVANCE_TO_WD(j, trig->wd);
 	if (j >= startdate) return j;
 
 	/* Must be next year */
 	y++;
 	while (trig->d > DaysInMonth(trig->m, y)) y++;
-	j = Julian(y, trig->m, trig->d);
+	j = DSE(y, trig->m, trig->d);
         ADVANCE_TO_WD(j, trig->wd);
 	return j;
 
     case GOT_WD+GOT_MON+GOT_YR:
 	if (y > trig->y || (y == trig->y && m > trig->m)) return -1;
 	if (trig->y > y || (trig->y == y && trig->m > m)) {
-	    j = Julian(trig->y, trig->m, 1);
+	    j = DSE(trig->y, trig->m, 1);
             ADVANCE_TO_WD(j, trig->wd);
 	    return j;
 	} else {
 	    j = startdate;
             ADVANCE_TO_WD(j, trig->wd);
-	    FromJulian(j, &y2, &m2, &d2);
+	    FromDSE(j, &y2, &m2, &d2);
 	    if (m2 == trig->m) return j; else return -1;
 	}
 
@@ -256,7 +257,7 @@ static int NextSimpleTrig(int startdate, Trigger *trig, int *err)
 	    *err = E_BAD_DATE;
 	    return -1;
 	}
-	j = Julian(trig->y, trig->m, trig->d);
+	j = DSE(trig->y, trig->m, trig->d);
         ADVANCE_TO_WD(j, trig->wd);
 	return j;
 
@@ -269,25 +270,25 @@ static int NextSimpleTrig(int startdate, Trigger *trig, int *err)
 
 /***************************************************************/
 /*                                                             */
-/*  JMonth - Given a Julian date, what's the month?            */
+/*  DSEMonth - Given a DSE date, what's the month?             */
 /*                                                             */
 /***************************************************************/
-static int JMonth(int jul)
+static int DSEMonth(int dse)
 {
     int y, m, d;
-    FromJulian(jul, &y, &m, &d);
+    FromDSE(dse, &y, &m, &d);
     return m;
 }
 
 /***************************************************************/
 /*                                                             */
-/*  JYear - Given a Julian date, what's the year?              */
+/*  DSEYear - Given a DSE date, what's the year?               */
 /*                                                             */
 /***************************************************************/
-static int JYear(int jul)
+static int DSEYear(int dse)
 {
     int y, m, d;
-    FromJulian(jul, &y, &m, &d);
+    FromDSE(dse, &y, &m, &d);
     return y;
 }
 
@@ -297,7 +298,7 @@ static int JYear(int jul)
 /*                                                             */
 /*  Given a trigger, compute the next trigger date.            */
 /*                                                             */
-/*  Returns the Julian date of next trigger, -1 if             */
+/*  Returns the DSE date of next trigger, -1 if                */
 /*  expired, -2 if can't compute trigger date.                 */
 /*                                                             */
 /***************************************************************/
@@ -439,7 +440,7 @@ AdjustTriggerForDuration(int today, int r, Trigger *trig, TimeTrig *tim, int sav
 	/* Change trigger date to today */
 	r = today;
 	if (DebugFlag & DB_PRTTRIG) {
-	    FromJulian(r, &y, &m, &d);
+	    FromDSE(r, &y, &m, &d);
 	    fprintf(ErrFp, "%s(%d): Trig(adj) = %s, %d %s, %d",
 		    FileName, LineNo,
 		    get_day_name(r % 7),
@@ -530,7 +531,7 @@ int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig *tim,
     *err = OK;
 
     /* But check for obvious problems... */
-    if (trig->localomit == 1 + 2 + 4 + 8 + 16 + 32 + 64) {
+    if ((WeekdayOmits | trig->localomit) == 0x7F) {
 	*err = E_2MANY_LOCALOMIT;
 	return -1;
     }
@@ -590,7 +591,7 @@ int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig *tim,
 		LastTrigValid = 1;
 	    }
 	    if (DebugFlag & DB_PRTTRIG) {
-		FromJulian(result, &y, &m, &d);
+		FromDSE(result, &y, &m, &d);
 		fprintf(ErrFp, "%s(%d): Trig = %s, %d %s, %d",
 			FileName, LineNo,
 			get_day_name(result % 7),
@@ -621,12 +622,10 @@ int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig *tim,
 		fprintf(ErrFp, "%s(%d): %s\n",
 			FileName, LineNo, ErrMsg[E_EXPIRED]);
 	    }
-	    if (result != -1) {
-		if (save_in_globals) {
-		    LastTriggerDate = result;
-		    LastTrigValid = 1;
-		}
-	    }
+            if (save_in_globals) {
+                LastTriggerDate = result;
+                LastTrigValid = 1;
+            }
 	    return -1;
 	}
 
@@ -639,12 +638,10 @@ int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig *tim,
 
 	/* Keep scanning... unless there's no point in doing it.*/
 	if (nextstart <= start) {
-	    if (result != -1) {
-		if (save_in_globals) {
-		    LastTriggerDate = result;
-		    LastTrigValid = 1;
-		}
-	    }
+            if (save_in_globals) {
+                LastTriggerDate = result;
+                LastTrigValid = 1;
+            }
 	    trig->expired = 1;
 	    if (DebugFlag & DB_PRTTRIG) {
 		fprintf(ErrFp, "%s(%d): %s\n",
@@ -661,40 +658,3 @@ int ComputeTriggerNoAdjustDuration(int today, Trigger *trig, TimeTrig *tim,
     return -1;
 }
 
-/***************************************************************/
-/*                                                             */
-/*  ComputeScanStart                                            */
-/*                                                             */
-/*  Figure out where to start scan from by examining SCANFROM  */
-/*  and DURATION                                               */
-/*                                                             */
-/***************************************************************/
-int
-ComputeScanStart(int today, Trigger *trig, TimeTrig *tt)
-{
-    int minutes, days;
-
-    /* If we don't have a time/duration, just use scanfrom */
-    if (tt->ttime == NO_TIME ||
-	tt->duration == NO_TIME) {
-	if (trig->scanfrom == NO_DATE) {
-	    return today;
-	}
-	return trig->scanfrom;
-    }
-
-    /* Calculate time-based SCANFROM */
-    minutes = tt->ttime + tt->duration - 1;
-
-    /* Figure out how many days to scan backwards from */
-    days = minutes / MINUTES_PER_DAY;
-
-    if (trig->scanfrom != NO_DATE) {
-	if (trig->scanfrom <= today - days) {
-	    return trig->scanfrom;
-	} else {
-	    return today - days;
-	}
-    }
-    return today - days;
-}
